# eminus

Main source code directory.

| File           | Description |
| :------------: | :---------: |
| atoms.py       | Atoms class definition |
| data.py        | Atom specific data |
| dft.py         | DFT routines |
| domains.py     | Domain generation |
| energies.py    | Energy object and calculation |
| gth.py         | GTH pseudopotential functions |
| io.py          | Input/output functions |
| localizer.py   | Localization routines |
| logger.py      | Logging configuration |
| minimizer.py   | Minimization algorithms |
| operators.py   | Plane-wave basis-set dependent operators |
| orbitals.py    | Orbital generation workflows |
| potentials.py  | Miscellaneous (pseudo-)potentials |
| scf.py         | SCF class definition |
| units.py       | Constants and unit conversion functions |
| tools.py       | Tools to calculate physical properties |
| utils.py       | Linear algebra and random utilities |
| version.py     | Package versions file |
| xc.py          | Exchange-correlation functionals |
